@@ -7,7 +7,8 @@
 #include "storage/data_database_writer.h"
 #include "storage/data_database_reader.h"
 #include "u8/u8_trace.h"
-#include "test_assert.h"
+#include "test_expect.h"
+#include "test_environment_assert.h"
 
 static void set_up(void);
 static void tear_down(void);
@@ -91,7 +92,7 @@ static void diagram_to_lifeline_consistency(void)
                                       DATA_DIAGRAM_FLAG_NONE,
                                       "4db26042-d7ce-4e2f-b8dc-cc9c9c61f39c"
                                     );
-        TEST_ASSERT_EQUAL_INT( U8_ERROR_NONE, data_err );
+        TEST_EXPECT_EQUAL_INT( U8_ERROR_NONE, data_err );
 
         root_diag_id = DATA_ROW_ID_VOID;
         ctrl_err = ctrl_diagram_controller_create_diagram ( diagram_ctrl,
@@ -99,8 +100,8 @@ static void diagram_to_lifeline_consistency(void)
                                                             CTRL_UNDO_REDO_ACTION_BOUNDARY_START_NEW,
                                                             &root_diag_id
                                                           );
-        TEST_ASSERT_EQUAL_INT( U8_ERROR_NONE, ctrl_err );
-        TEST_ASSERT( DATA_ROW_ID_VOID != root_diag_id );
+        TEST_EXPECT_EQUAL_INT( U8_ERROR_NONE, ctrl_err );
+        TEST_EXPECT( DATA_ROW_ID_VOID != root_diag_id );
         data_diagram_destroy ( &root_diagram );
     }
 
@@ -118,7 +119,7 @@ static void diagram_to_lifeline_consistency(void)
                                       DATA_DIAGRAM_FLAG_NONE,
                                       "e89207d2-c7d2-4996-9bfc-bc6e1a9ff6b3"
                                     );
-        TEST_ASSERT_EQUAL_INT( U8_ERROR_NONE, data_err );
+        TEST_EXPECT_EQUAL_INT( U8_ERROR_NONE, data_err );
 
         child_diag_id = DATA_ROW_ID_VOID;
         ctrl_err = ctrl_diagram_controller_create_diagram ( diagram_ctrl,
@@ -126,8 +127,8 @@ static void diagram_to_lifeline_consistency(void)
                                                             CTRL_UNDO_REDO_ACTION_BOUNDARY_APPEND,
                                                             &child_diag_id
                                                           );
-        TEST_ASSERT_EQUAL_INT( U8_ERROR_NONE, ctrl_err );
-        TEST_ASSERT( child_diag_id != DATA_ROW_ID_VOID );
+        TEST_EXPECT_EQUAL_INT( U8_ERROR_NONE, ctrl_err );
+        TEST_EXPECT( child_diag_id != DATA_ROW_ID_VOID );
         data_diagram_destroy ( &child_diagram );
     }
 
@@ -144,7 +145,7 @@ static void diagram_to_lifeline_consistency(void)
                                              4500,
                                              450000
                                            );
-        TEST_ASSERT_EQUAL_INT( U8_ERROR_NONE, data_err );
+        TEST_EXPECT_EQUAL_INT( U8_ERROR_NONE, data_err );
 
         classifier_id = DATA_ROW_ID_VOID;
         ctrl_err = ctrl_classifier_controller_create_classifier ( classifier_ctrl,
@@ -152,8 +153,8 @@ static void diagram_to_lifeline_consistency(void)
                                                                   CTRL_UNDO_REDO_ACTION_BOUNDARY_APPEND,
                                                                   &classifier_id
                                                                 );
-        TEST_ASSERT_EQUAL_INT( U8_ERROR_NONE, ctrl_err );
-        TEST_ASSERT( DATA_ROW_ID_VOID != classifier_id );
+        TEST_EXPECT_EQUAL_INT( U8_ERROR_NONE, ctrl_err );
+        TEST_EXPECT( DATA_ROW_ID_VOID != classifier_id );
         data_classifier_destroy ( &new_classifier );
     }
 
@@ -174,9 +175,9 @@ static void diagram_to_lifeline_consistency(void)
                                                                    CTRL_UNDO_REDO_ACTION_BOUNDARY_APPEND,
                                                                    &root_diag_element_id
                                                                  );
-        TEST_ASSERT_EQUAL_INT( U8_ERROR_NONE, ctrl_err );
+        TEST_EXPECT_EQUAL_INT( U8_ERROR_NONE, ctrl_err );
         data_diagramelement_destroy ( &new_diagele );
-        TEST_ASSERT( DATA_ROW_ID_VOID != root_diag_element_id );
+        TEST_EXPECT( DATA_ROW_ID_VOID != root_diag_element_id );
     }
 
     /* create one diagramelement for the child diagram */
@@ -196,27 +197,27 @@ static void diagram_to_lifeline_consistency(void)
                                                                    CTRL_UNDO_REDO_ACTION_BOUNDARY_APPEND,
                                                                    &child_diag_element_id
                                                                  );
-        TEST_ASSERT_EQUAL_INT( U8_ERROR_NONE, ctrl_err );
+        TEST_EXPECT_EQUAL_INT( U8_ERROR_NONE, ctrl_err );
         data_diagramelement_destroy ( &new_diagele2 );
-        TEST_ASSERT( DATA_ROW_ID_VOID != child_diag_element_id );
+        TEST_EXPECT( DATA_ROW_ID_VOID != child_diag_element_id );
     }
 
     /* change the type of the child diagram to DATA_DIAGRAM_TYPE_UML_SEQUENCE_DIAGRAM */
     {
         ctrl_err = ctrl_diagram_controller_update_diagram_type ( diagram_ctrl, child_diag_id, DATA_DIAGRAM_TYPE_UML_SEQUENCE_DIAGRAM );
-        TEST_ASSERT_EQUAL_INT( U8_ERROR_NONE, ctrl_err );
+        TEST_EXPECT_EQUAL_INT( U8_ERROR_NONE, ctrl_err );
     }
 
     /* change the type of the child diagram to DATA_DIAGRAM_TYPE_UML_CLASS_DIAGRAM */
     {
         ctrl_err = ctrl_diagram_controller_update_diagram_type ( diagram_ctrl, child_diag_id, DATA_DIAGRAM_TYPE_UML_CLASS_DIAGRAM );
-        TEST_ASSERT_EQUAL_INT( U8_ERROR_NONE, ctrl_err );
+        TEST_EXPECT_EQUAL_INT( U8_ERROR_NONE, ctrl_err );
     }
 
     /* change the type of the child diagram to DATA_DIAGRAM_TYPE_UML_SEQUENCE_DIAGRAM */
     {
         ctrl_err = ctrl_diagram_controller_update_diagram_type ( diagram_ctrl, child_diag_id, DATA_DIAGRAM_TYPE_UML_SEQUENCE_DIAGRAM );
-        TEST_ASSERT_EQUAL_INT( U8_ERROR_NONE, ctrl_err );
+        TEST_EXPECT_EQUAL_INT( U8_ERROR_NONE, ctrl_err );
     }
 
     /* check that the classifier now has one feature of type DATA_FEATURE_TYPE_LIFELINE */
@@ -230,18 +231,18 @@ static void diagram_to_lifeline_consistency(void)
                                                                         &features,
                                                                         &feature_count
                                                                       );
-        TEST_ASSERT_EQUAL_INT( U8_ERROR_NONE, data_err );
-        TEST_ASSERT_EQUAL_INT( 1, feature_count );
-        TEST_ASSERT_EQUAL_INT( DATA_FEATURE_TYPE_LIFELINE, data_feature_get_main_type( &(features[0]) ) );
+        TEST_EXPECT_EQUAL_INT( U8_ERROR_NONE, data_err );
+        TEST_EXPECT_EQUAL_INT( 1, feature_count );
+        TEST_EXPECT_EQUAL_INT( DATA_FEATURE_TYPE_LIFELINE, data_feature_get_main_type( &(features[0]) ) );
     }
 
     /* check that this is referenced */
     {
         data_diagramelement_t check_diagele2;
         data_err = data_database_reader_get_diagramelement_by_id ( &db_reader, child_diag_element_id, &check_diagele2 );
-        TEST_ASSERT_EQUAL_INT( U8_ERROR_NONE, data_err );
+        TEST_EXPECT_EQUAL_INT( U8_ERROR_NONE, data_err );
 
-        TEST_ASSERT_EQUAL_INT( data_feature_get_row_id( &(features[0])), data_diagramelement_get_focused_feature_row_id( &check_diagele2 ) );
+        TEST_EXPECT_EQUAL_INT( data_feature_get_row_id( &(features[0])), data_diagramelement_get_focused_feature_row_id( &check_diagele2 ) );
 
         data_diagramelement_destroy ( &check_diagele2 );
     }
@@ -252,13 +253,13 @@ static void diagram_to_lifeline_consistency(void)
                                                                    child_diag_element_id,
                                                                    CTRL_UNDO_REDO_ACTION_BOUNDARY_START_NEW
                                                                  );
-        TEST_ASSERT_EQUAL_INT( U8_ERROR_NONE, ctrl_err );
+        TEST_EXPECT_EQUAL_INT( U8_ERROR_NONE, ctrl_err );
 
         ctrl_err = ctrl_diagram_controller_delete_diagram ( diagram_ctrl,
                                                             child_diag_id,
                                                             CTRL_UNDO_REDO_ACTION_BOUNDARY_APPEND
                                                           );
-        TEST_ASSERT_EQUAL_INT( U8_ERROR_NONE, ctrl_err );
+        TEST_EXPECT_EQUAL_INT( U8_ERROR_NONE, ctrl_err );
     }
 
     /* check that the feature of type DATA_FEATURE_TYPE_LIFELINE is deleted */
@@ -269,8 +270,8 @@ static void diagram_to_lifeline_consistency(void)
                                                                         &features,
                                                                         &feature_count
                                                                       );
-        TEST_ASSERT_EQUAL_INT( U8_ERROR_NONE, data_err );
-        TEST_ASSERT_EQUAL_INT( 0, feature_count );
+        TEST_EXPECT_EQUAL_INT( U8_ERROR_NONE, data_err );
+        TEST_EXPECT_EQUAL_INT( 0, feature_count );
     }
 }
 
@@ -298,7 +299,7 @@ static void diagramelement_to_lifeline_consistency(void)
                                       DATA_DIAGRAM_FLAG_NONE,
                                       "bad218e0-d633-4a2c-b0bb-d636c28d3496"
                                     );
-        TEST_ASSERT_EQUAL_INT( U8_ERROR_NONE, data_err );
+        TEST_EXPECT_EQUAL_INT( U8_ERROR_NONE, data_err );
 
         root_diag_id = DATA_ROW_ID_VOID;
         ctrl_err = ctrl_diagram_controller_create_diagram ( diagram_ctrl,
@@ -306,8 +307,8 @@ static void diagramelement_to_lifeline_consistency(void)
                                                             CTRL_UNDO_REDO_ACTION_BOUNDARY_START_NEW,
                                                             &root_diag_id
         );
-        TEST_ASSERT_EQUAL_INT( U8_ERROR_NONE, ctrl_err );
-        TEST_ASSERT( DATA_ROW_ID_VOID != root_diag_id );
+        TEST_EXPECT_EQUAL_INT( U8_ERROR_NONE, ctrl_err );
+        TEST_EXPECT( DATA_ROW_ID_VOID != root_diag_id );
         data_diagram_destroy ( &root_diagram );
     }
 
@@ -324,7 +325,7 @@ static void diagramelement_to_lifeline_consistency(void)
                                              4500,
                                              450000
                                            );
-        TEST_ASSERT_EQUAL_INT( U8_ERROR_NONE, data_err );
+        TEST_EXPECT_EQUAL_INT( U8_ERROR_NONE, data_err );
 
         classifier_id = DATA_ROW_ID_VOID;
         ctrl_err = ctrl_classifier_controller_create_classifier ( classifier_ctrl,
@@ -332,8 +333,8 @@ static void diagramelement_to_lifeline_consistency(void)
                                                                   CTRL_UNDO_REDO_ACTION_BOUNDARY_START_NEW,
                                                                   &classifier_id
         );
-        TEST_ASSERT_EQUAL_INT( U8_ERROR_NONE, ctrl_err );
-        TEST_ASSERT( DATA_ROW_ID_VOID != classifier_id );
+        TEST_EXPECT_EQUAL_INT( U8_ERROR_NONE, ctrl_err );
+        TEST_EXPECT( DATA_ROW_ID_VOID != classifier_id );
         data_classifier_destroy ( &new_classifier );
     }
 
@@ -354,9 +355,9 @@ static void diagramelement_to_lifeline_consistency(void)
                                                                    CTRL_UNDO_REDO_ACTION_BOUNDARY_APPEND,
                                                                    &first_diag_element_id
                                                                  );
-        TEST_ASSERT_EQUAL_INT( U8_ERROR_NONE, ctrl_err );
+        TEST_EXPECT_EQUAL_INT( U8_ERROR_NONE, ctrl_err );
         data_diagramelement_destroy ( &new_diagele );
-        TEST_ASSERT( DATA_ROW_ID_VOID != first_diag_element_id );
+        TEST_EXPECT( DATA_ROW_ID_VOID != first_diag_element_id );
     }
 
     /* create second diagramelement for the classifier */
@@ -376,9 +377,9 @@ static void diagramelement_to_lifeline_consistency(void)
                                                                    CTRL_UNDO_REDO_ACTION_BOUNDARY_APPEND,
                                                                    &second_diag_element_id
                                                                  );
-        TEST_ASSERT_EQUAL_INT( U8_ERROR_NONE, ctrl_err );
+        TEST_EXPECT_EQUAL_INT( U8_ERROR_NONE, ctrl_err );
         data_diagramelement_destroy ( &new_diagele2 );
-        TEST_ASSERT( DATA_ROW_ID_VOID != second_diag_element_id );
+        TEST_EXPECT( DATA_ROW_ID_VOID != second_diag_element_id );
     }
 
     /* check that the classifier now has two features of type DATA_FEATURE_TYPE_LIFELINE */
@@ -392,10 +393,10 @@ static void diagramelement_to_lifeline_consistency(void)
                                                                         &features,
                                                                         &feature_count
                                                                       );
-        TEST_ASSERT_EQUAL_INT( U8_ERROR_NONE, data_err );
-        TEST_ASSERT_EQUAL_INT( 2, feature_count );
-        TEST_ASSERT_EQUAL_INT( DATA_FEATURE_TYPE_LIFELINE, data_feature_get_main_type( &(features[0]) ) );
-        TEST_ASSERT_EQUAL_INT( DATA_FEATURE_TYPE_LIFELINE, data_feature_get_main_type( &(features[1]) ) );
+        TEST_EXPECT_EQUAL_INT( U8_ERROR_NONE, data_err );
+        TEST_EXPECT_EQUAL_INT( 2, feature_count );
+        TEST_EXPECT_EQUAL_INT( DATA_FEATURE_TYPE_LIFELINE, data_feature_get_main_type( &(features[0]) ) );
+        TEST_EXPECT_EQUAL_INT( DATA_FEATURE_TYPE_LIFELINE, data_feature_get_main_type( &(features[1]) ) );
     }
 
     /* delete the first diagramelement (but not the classifier) */
@@ -404,7 +405,7 @@ static void diagramelement_to_lifeline_consistency(void)
                                                                    first_diag_element_id,
                                                                    CTRL_UNDO_REDO_ACTION_BOUNDARY_START_NEW
                                                                  );
-        TEST_ASSERT_EQUAL_INT( U8_ERROR_NONE, ctrl_err );
+        TEST_EXPECT_EQUAL_INT( U8_ERROR_NONE, ctrl_err );
     }
 
     /* check that one feature of type DATA_FEATURE_TYPE_LIFELINE is deleted */
@@ -415,18 +416,18 @@ static void diagramelement_to_lifeline_consistency(void)
                                                                         &features,
                                                                         &feature_count
                                                                       );
-        TEST_ASSERT_EQUAL_INT( U8_ERROR_NONE, data_err );
-        TEST_ASSERT_EQUAL_INT( 1, feature_count );
-        TEST_ASSERT_EQUAL_INT( DATA_FEATURE_TYPE_LIFELINE, data_feature_get_main_type( &(features[0]) ) );
+        TEST_EXPECT_EQUAL_INT( U8_ERROR_NONE, data_err );
+        TEST_EXPECT_EQUAL_INT( 1, feature_count );
+        TEST_EXPECT_EQUAL_INT( DATA_FEATURE_TYPE_LIFELINE, data_feature_get_main_type( &(features[0]) ) );
     }
 
     /* check that this is referenced */
     {
         data_diagramelement_t check_diagele2;
         data_err = data_database_reader_get_diagramelement_by_id ( &db_reader, second_diag_element_id, &check_diagele2 );
-        TEST_ASSERT_EQUAL_INT( U8_ERROR_NONE, data_err );
+        TEST_EXPECT_EQUAL_INT( U8_ERROR_NONE, data_err );
 
-        TEST_ASSERT_EQUAL_INT( data_feature_get_row_id( &(features[0])), data_diagramelement_get_focused_feature_row_id( &check_diagele2 ) );
+        TEST_EXPECT_EQUAL_INT( data_feature_get_row_id( &(features[0])), data_diagramelement_get_focused_feature_row_id( &check_diagele2 ) );
 
         data_diagramelement_destroy ( &check_diagele2 );
     }
@@ -470,23 +471,23 @@ static void no_hidden_relationships(void)
     /* delete the local diagramelement of the test classifier */
     const u8_error_t c_err
         = ctrl_diagram_controller_delete_diagramelement ( diagram_ctrl, test_local_diagele, CTRL_UNDO_REDO_ACTION_BOUNDARY_START_NEW );
-    TEST_ASSERT_EQUAL_INT( U8_ERROR_NONE, c_err );
+    TEST_EXPECT_EQUAL_INT( U8_ERROR_NONE, c_err );
 
     /* is local rel deleted? */
     data_relationship_t probe;
     const u8_error_t local_err
         = data_database_reader_get_relationship_by_id( &db_reader, local_rel, &probe );
-    TEST_ASSERT_EQUAL_INT( U8_ERROR_DB_STRUCTURE, local_err );
+    TEST_EXPECT_EQUAL_INT( U8_ERROR_DB_STRUCTURE, local_err );
 
     /* is double rel existing? */
     const u8_error_t double_err
         = data_database_reader_get_relationship_by_id( &db_reader, double_rel, &probe );
-    TEST_ASSERT_EQUAL_INT( U8_ERROR_NONE, double_err );
+    TEST_EXPECT_EQUAL_INT( U8_ERROR_NONE, double_err );
 }
 
 
 /*
- * Copyright 2018-2022 Andreas Warnke
+ * Copyright 2018-2023 Andreas Warnke
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
