@@ -175,7 +175,7 @@ static const char *XHTML_DIAGRAM_TITLE_END[XHTML_DIAGRAM_MAX_DEPTH]
 static const char XHTML_DIAGRAM_IMG_START[]
     = "\n<div class=\"mediaobject\"><img src=\"";
 static const char XHTML_DIAGRAM_IMG_END[]
-    = ".png\" alt=\"\" /></div>";
+    = ".png\" width=\"840\" alt=\"\" /></div>";
 static const char XHTML_DIAGRAM_END[]
     = "\n</div>";
 
@@ -1363,7 +1363,7 @@ int xhtml_element_writer_write_footer( xhtml_element_writer_t *this_ )
 
 
 /*
-Copyright 2017-2022 Andreas Warnke
+Copyright 2017-2023 Andreas Warnke
 
 Licensed under the Apache License, Version 2.0 (the "License");
 you may not use this file except in compliance with the License.
