@@ -155,18 +155,15 @@ void pencil_layouter_define_grid ( pencil_layouter_t *this_, geometry_rectangle_
     U8_TRACE_END();
 }
 
-void pencil_layouter_layout_elements ( pencil_layouter_t *this_, PangoLayout *font_layout, data_stat_t *io_layout_stat )
+void pencil_layouter_layout_elements ( pencil_layouter_t *this_, PangoLayout *font_layout )
 {
     U8_TRACE_BEGIN();
     assert( font_layout != NULL );
 
     /* get the diagram data */
-    const layout_diagram_t *const the_diagram
-        = pencil_layout_data_get_diagram_ptr( &((*this_).layout_data) );
-    const data_diagram_t *const diagram_data
-        = layout_diagram_get_data_const ( the_diagram );
-    const data_diagram_type_t diag_type
-        = data_diagram_get_diagram_type ( diagram_data );
+    const layout_diagram_t *const the_diagram = pencil_layout_data_get_diagram_ptr( &((*this_).layout_data) );
+    const data_diagram_t *const diagram_data = layout_diagram_get_data_const ( the_diagram );
+    const data_diagram_type_t diag_type = data_diagram_get_diagram_type ( diagram_data );
 
     /* adjust the default classifier rectangle */
     pencil_layouter_private_propose_default_classifier_size( this_ );
@@ -255,10 +252,6 @@ void pencil_layouter_layout_elements ( pencil_layouter_t *this_, PangoLayout *fo
         pencil_rel_label_layouter_do_layout( &((*this_).relationship_label_layouter), font_layout );
     }
 
-    if ( io_layout_stat != NULL )
-    {
-        pencil_layout_data_get_statistics( &((*this_).layout_data), io_layout_stat );
-    }
     U8_TRACE_END();
 }
 
@@ -1024,7 +1017,7 @@ pencil_error_t pencil_layouter_get_relationship_order_at_pos ( const pencil_layo
 
 
 /*
-Copyright 2017-2022 Andreas Warnke
+Copyright 2017-2023 Andreas Warnke
 
 Licensed under the Apache License, Version 2.0 (the "License");
 you may not use this file except in compliance with the License.
